@@ -115,12 +115,19 @@ execProcess cspec spec cgii req = do
 #endif
 #if __GLASGOW_HASKELL__ >= 707
       , delegate_ctlc = False
+#endif
+#if __GLASGOW_HASKELL__ >= 800
+      , detach_console = False
+      , create_new_console = False
+      , new_session = False
+      , child_group = Nothing
+      , child_user = Nothing
 #endif
       }
     (prog, scriptName, pathinfo) =
         pathinfoToCGI (cgiSrc cgii)
                       (cgiDst cgii)
-                      (fromByteString (rawPathInfo req))
+                      (rawPathInfo req)
                       (indexCgi spec)
 
 makeEnv :: Request -> String -> String -> String -> ByteString ->
