@@ -13,7 +13,6 @@ import Data.ByteString (ByteString)
 import qualified Data.ByteString as BS (uncons)
 import qualified Data.ByteString.Char8 as BS hiding (uncons)
 import Data.Conduit
-import Data.Default.Class
 import qualified Network.HTTP.Client as H
 import Network.HTTP.Types
 import Network.Wai.Application.Classic.Conduit
@@ -54,23 +53,23 @@ headerToBeRelay (k,_)
 ----------------------------------------------------------------
 
 reqToHReq :: Request -> RevProxyRoute -> H.Request
-reqToHReq req route = def {
+reqToHReq req route = H.defaultRequest {
     H.host           = revProxyDomain route
   , H.port           = revProxyPort route
   , H.secure         = False -- FIXME: upstream is HTTP only
   , H.requestHeaders = addForwardedFor req $ filter headerToBeRelay hdr
-  , H.path           = pathByteString path'
+  , H.path           = path'
   , H.queryString    = dropQuestion query
   , H.requestBody    = bodyToHBody len body
   , H.method         = requestMethod req
   , H.proxy          = Nothing
 --  , H.rawBody        = False
   , H.decompress     = const True
-  , H.checkStatus    = \_ _ _ -> Nothing -- FIXME
+  , H.checkResponse  = \_ _ -> return ()
   , H.redirectCount  = 0
   }
   where
-    path = fromByteString $ rawPathInfo req
+    path = rawPathInfo req
     src = revProxySrc route
     dst = revProxyDst route
     hdr = requestHeaders req
